/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

gboolean gsh_button_exits=FALSE;

void
gsh_test_exit()
{
	if (gsh_button_exits)
		exit(0);
}

void
system_cb(GtkWidget * widget, gpointer data)
{
	UNUSED(widget);

	antiright_system(data);
	gsh_test_exit();
}

void
entry_cb(GtkWidget * widget, gpointer data)
{
	gchar          *command;
	const gchar    *input;

	input = gtk_entry_get_text(GTK_ENTRY(widget));
	asprintf(&command, "%s %s", (char *) data, (char *) input);
	system_cb(NULL, command);
	free(command);
}

